@@ -127,11 +127,8 @@ impl RenameBranchComponent {
 	///
 	pub fn rename_branch(&mut self) {
 		if let Some(br) = &self.branch_ref {
-			let res = sync::rename_branch(
-				CWD,
-				br,
-				self.input.get_text().as_str(),
-			);
+			let res =
+				sync::rename_branch(CWD, br, self.input.get_text());
 
 			match res {
 				Ok(_) => {
