@@ -30,6 +30,7 @@ mod notify_mutex;
 mod profiler;
 mod queue;
 mod spinner;
+mod string_utils;
 mod strings;
 mod tabs;
 mod ui;
@@ -76,12 +77,16 @@ pub enum QueueEvent {
 	InputEvent(InputEvent),
 }
 
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum SyntaxHighlightProgress {
+	Progress,
+	Done,
+}
+
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum AsyncAppNotification {
 	///
-	SyntaxHighlighting,
-	///
-	RemoteTags,
+	SyntaxHighlighting(SyntaxHighlightProgress),
 }
 
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -224,8 +229,8 @@ fn draw<B: Backend>(
 		terminal.resize(terminal.size()?)?;
 	}
 
-	terminal.draw(|mut f| {
-		if let Err(e) = app.draw(&mut f) {
+	terminal.draw(|f| {
+		if let Err(e) = app.draw(f) {
 			log::error!("failed to draw: {:?}", e);
 		}
 	})?;
